<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">

<!--
SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.

SPDX-License-Identifier: LGPL-3.0-or-later
-->

<context>
    <name>DAboutDialog</name>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="190"/>
        <source>Acknowledgements</source>
        <translation>Agradecimentos</translation>
    </message>
    <message>
        <location filename="../widgets/dapplication.cpp" line="1528"/>
        <source>Version: %1</source>
        <translation>Versão: %1</translation>
    </message>
    <message>
        <location filename="../widgets/dapplication.cpp" line="1532"/>
        <source>%1 is released under %2</source>
        <translation>%1 é lançado em %2</translation>
    </message>
</context>
<context>
    <name>DCrumbEdit</name>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="840"/>
        <source>Black</source>
        <translation>Preto</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="843"/>
        <source>White</source>
        <translation>Branco</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="846"/>
        <source>Dark Gray</source>
        <translation>Cinza Escuro</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="849"/>
        <source>Gray</source>
        <translation>Cinza</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="852"/>
        <source>Light Gray</source>
        <translation>Cinza Claro</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="855"/>
        <source>Red</source>
        <translation>Vermelho</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="858"/>
        <source>Green</source>
        <translation>Verde</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="861"/>
        <source>Blue</source>
        <translation>Azul</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="864"/>
        <source>Cyan</source>
        <translation>Ciano</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="867"/>
        <source>Magenta</source>
        <translation>Magenta</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="870"/>
        <source>Yellow</source>
        <translation>Amarelo</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="873"/>
        <source>Dark Red</source>
        <translation>Vermelho Escuro</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="876"/>
        <source>Dark Green</source>
        <translation>Verde Escuro</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="879"/>
        <source>Dark Blue</source>
        <translation>Azul Escuro</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="882"/>
        <source>Dark Cyan</source>
        <translation>Ciano Escuro</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="885"/>
        <source>Dark Magenta</source>
        <translation>Magenta Escuro</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="888"/>
        <source>Dark Yellow</source>
        <translation>Amarelo Escuro</translation>
    </message>
</context>
<context>
    <name>DInputDialog</name>
    <message>
        <location filename="../widgets/dinputdialog.cpp" line="42"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../widgets/dinputdialog.cpp" line="43"/>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
</context>
<context>
    <name>DKeySequenceEdit</name>
    <message>
        <location filename="../widgets/dkeysequenceedit.cpp" line="86"/>
        <source>Enter a new shortcut</source>
        <translation>Insira um novo atalho</translation>
    </message>
</context>
<context>
    <name>DLineEdit</name>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="562"/>
        <source>Stop reading</source>
        <translation>Parar de ler</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="564"/>
        <source>Text to Speech</source>
        <translation>Texto em Voz</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="587"/>
        <source>Translate</source>
        <translation>Traduzir</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="609"/>
        <source>Speech To Text</source>
        <translation>Voz em Texto</translation>
    </message>
</context>
<context>
    <name>DPrintPreviewDialogPrivate</name>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="235"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1181"/>
        <source>Advanced</source>
        <translation>Avançado</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="258"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="259"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1597"/>
        <source>Print</source>
        <comment>button</comment>
        <translation>Imprimir</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="275"/>
        <source>Basic</source>
        <translation>Básico</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="290"/>
        <source>Printer</source>
        <translation>Impressora</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="304"/>
        <source>Copies</source>
        <translation>Cópias</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="324"/>
        <source>Page range</source>
        <translation>Intervalo de páginas</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="326"/>
        <source>All</source>
        <translation>Tudo</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="327"/>
        <source>Current page</source>
        <translation>Página atual</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="328"/>
        <source>Select pages</source>
        <translation>Selecionar páginas</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="343"/>
        <source>Orientation</source>
        <translation>Orientação</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="367"/>
        <source>Portrait</source>
        <translation>Retrato</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="377"/>
        <source>Landscape</source>
        <translation>Paisagem</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="405"/>
        <source>Pages</source>
        <translation>Páginas</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="415"/>
        <source>Color mode</source>
        <translation>Modo de cores</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="417"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1554"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1621"/>
        <source>Color</source>
        <translation>Cor</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="417"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1606"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1621"/>
        <source>Grayscale</source>
        <translation>Escala cinza</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="428"/>
        <source>Margins</source>
        <translation>Margens</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="430"/>
        <source>Narrow (mm)</source>
        <translation>Estreita (mm)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="430"/>
        <source>Normal (mm)</source>
        <translation>Normal (mm)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="430"/>
        <source>Moderate (mm)</source>
        <translation>Moderada (mm)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="430"/>
        <source>Customize (mm)</source>
        <translation>Personalizada (mm)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="436"/>
        <source>Top</source>
        <translation>Superior</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="439"/>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="442"/>
        <source>Bottom</source>
        <translation>Inferior</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="445"/>
        <source>Right</source>
        <translation>Direita</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="490"/>
        <source>Scaling</source>
        <translation>Escala</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="504"/>
        <source>Actual size</source>
        <translation>Tamanho atual</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="513"/>
        <source>Scale</source>
        <translation>Escala</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="544"/>
        <source>Paper</source>
        <translation>Papel</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="554"/>
        <source>Paper size</source>
        <translation>Tamanho do papel</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="567"/>
        <source>Print Layout</source>
        <translation>Layout de Impressão</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="578"/>
        <source>Duplex</source>
        <translation>Duplex</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="591"/>
        <source>N-up printing</source>
        <translation>Impressão N-up</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="593"/>
        <source>2 pages/sheet, 1×2</source>
        <translation>2 páginas/folha, 1×2</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="593"/>
        <source>4 pages/sheet, 2×2</source>
        <translation>4 páginas/folha, 2×2</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="593"/>
        <source>6 pages/sheet, 2×3</source>
        <translation>6 páginas/folha, 2×3</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="593"/>
        <source>9 pages/sheet, 3×3</source>
        <translation>9 páginas/folha, 3×3</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="593"/>
        <source>16 pages/sheet, 4×4</source>
        <translation>16 páginas/folha, 4×4</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="602"/>
        <source>Layout direction</source>
        <translation>Orientação do layout</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="647"/>
        <source>Page Order</source>
        <translation>Ordem das Páginas</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="658"/>
        <source>Collate pages</source>
        <translation>Agrupar páginas</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="664"/>
        <source>Print pages in order</source>
        <translation>Imprimir páginas em ordem</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="666"/>
        <source>Front to back</source>
        <translation>De frente para trás</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="666"/>
        <source>Back to front</source>
        <translation>De trás para frente</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="690"/>
        <source>Watermark</source>
        <translation>Marca d&apos;água</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="701"/>
        <source>Add watermark</source>
        <translation>Adicionar marca d&apos;água</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="743"/>
        <source>Text watermark</source>
        <translation>Marca d&apos;água de texto</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="745"/>
        <source>Confidential</source>
        <translation>Confidencial</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="745"/>
        <source>Draft</source>
        <translation>Rascunho</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="745"/>
        <source>Sample</source>
        <translation>Amostra</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="745"/>
        <source>Custom</source>
        <translation>Personalizado</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="753"/>
        <source>Input your text</source>
        <translation>Insira o texto</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="776"/>
        <source>Picture watermark</source>
        <translation>Marca d&apos;água de imagem</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="797"/>
        <source>Layout</source>
        <translation>Layout</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="799"/>
        <source>Tile</source>
        <translation>Ladrilho</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="799"/>
        <source>Center</source>
        <translation>Centro</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="810"/>
        <source>Angle</source>
        <translation>Ângulo</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="826"/>
        <source>Size</source>
        <translation>Tamanho</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="847"/>
        <source>Transparency</source>
        <translation>Transparência</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="904"/>
        <source>Print to PDF</source>
        <translation>Imprimir em PDF</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="905"/>
        <source>Save as Image</source>
        <translation>Salvar como Imagem</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1177"/>
        <source>Collapse</source>
        <translation>Recolher</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1300"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1307"/>
        <source>Flip on short edge</source>
        <translation>Virar na borda curta</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1303"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1306"/>
        <source>Flip on long edge</source>
        <translation>Virar na borda longa</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1397"/>
        <source>Input page numbers please</source>
        <translation>Insira o números de páginas</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1400"/>
        <source>Maximum page number reached</source>
        <translation>O número máximo de páginas foi atingido</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1403"/>
        <source>Input English comma please</source>
        <translation>Insira uma vírgula</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1406"/>
        <source>Input page numbers like this: 1,3,5-7,11-15,18,21</source>
        <translation>Insira os números das páginas assim: 1, 3, 5-7, 11-15, 18, 21</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1559"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Salvar</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2174"/>
        <source>*.pdf</source>
        <translation>*.pdf</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1673"/>
        <source>For example, 1,3,5-7,11-15,18,21</source>
        <translation>Por exemplo: 1, 3, 5-7, 11-15, 18, 21</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2174"/>
        <source>Save as PDF</source>
        <translation>Salvar como PDF</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2213"/>
        <source>Save as image</source>
        <translation>Salvar como imagem</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2215"/>
        <source>Images</source>
        <translation>Imagens</translation>
    </message>
</context>
<context>
    <name>DPrintPreviewWidget</name>
    <message>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1619"/>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1622"/>
        <source>Confidential</source>
        <translation>Confidencial</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1637"/>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1640"/>
        <source>Draft</source>
        <translation>Rascunho</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1655"/>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1658"/>
        <source>Sample</source>
        <translation>Amostra</translation>
    </message>
</context>
<context>
    <name>DSearchEdit</name>
    <message>
        <location filename="../widgets/dsearchedit.cpp" line="297"/>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
</context>
<context>
    <name>DSettingsDialog</name>
    <message>
        <location filename="../widgets/dsettingswidgetfactory.cpp" line="78"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../widgets/dsettingswidgetfactory.cpp" line="79"/>
        <source>Replace</source>
        <translation>Substituir</translation>
    </message>
    <message>
        <location filename="../widgets/dsettingswidgetfactory.cpp" line="81"/>
        <source>This shortcut conflicts with %1, click on Add to make this shortcut effective immediately</source>
        <translation>Este atalho entra em conflito com %1; clique em Adicionar para efetivar este atalho</translation>
    </message>
</context>
<context>
    <name>DShortcutEdit</name>
    <message>
        <location filename="../widgets/dshortcutedit.cpp" line="31"/>
        <source>Please input a new shortcut</source>
        <translation>Insira um novo atalho</translation>
    </message>
    <message>
        <location filename="../widgets/dshortcutedit.cpp" line="102"/>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
</context>
<context>
    <name>DSplitScreenWidget</name>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="215"/>
        <source>Unmaximize</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="218"/>
        <source>Maximize</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="258"/>
        <source>Tile window to left of screen</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="259"/>
        <source>Tile window to right of screen</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DTextEdit</name>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="185"/>
        <source>Stop reading</source>
        <translation>Parar de ler</translation>
    </message>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="187"/>
        <source>Text to Speech</source>
        <translation>Texto em Voz</translation>
    </message>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="210"/>
        <source>Translate</source>
        <translation>Traduzir</translation>
    </message>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="232"/>
        <source>Speech To Text</source>
        <translation>Voz em Texto</translation>
    </message>
</context>
<context>
    <name>PickColorWidget</name>
    <message>
        <location filename="../widgets/dprintpickcolorwidget.cpp" line="110"/>
        <source>Color</source>
        <translation>Cor</translation>
    </message>
</context>
<context>
    <name>QLineEdit</name>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="536"/>
        <source>&amp;Copy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="539"/>
        <source>Cu&amp;t</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="545"/>
        <source>Select All</source>
        <translation>Selecionar Tudo</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../widgets/dsimplelistview.cpp" line="1366"/>
        <source>No search result</source>
        <translation>Nenhum resultado</translation>
    </message>
    <message>
        <location filename="../widgets/private/settings/content.cpp" line="340"/>
        <source>Restore Defaults</source>
        <translation>Restaurar Padrões</translation>
    </message>
</context>
<context>
    <name>QWidgetTextControl</name>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="177"/>
        <source>Select All</source>
        <translation>Selecionar Tudo</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <location filename="../widgets/private/settings/shortcutedit.cpp" line="117"/>
        <source>Please enter a new shortcut</source>
        <translation>Insira um novo atalho</translation>
    </message>
</context>
<context>
    <name>TitleBarMenu</name>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="770"/>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="772"/>
        <source>Light Theme</source>
        <translation>Claro</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="773"/>
        <source>Dark Theme</source>
        <translation>Escuro</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="774"/>
        <source>System Theme</source>
        <translation>Padrão</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="799"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="807"/>
        <source>Feedback</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="814"/>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="821"/>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
</context>
</TS>